#
# spec file for package makedepend
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           makedepend
Version:        1.0.9
Release:        1.8
Summary:        Utility to create dependencies in makefiles
License:        MIT
Group:          Development/Tools/Building
URL:            https://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/util/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM https://gitlab.freedesktop.org/xorg/util/makedepend/-/merge_requests/10
# For autogen.sh
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
# This was part of the xorg-x11-util-devel package up to version 7.6
Conflicts:      xorg-x11-util-devel <= 7.6

%description
The makedepend program reads each sourcefile in sequence and parses it
like a C-preprocessor so that it can correctly tell which #include
directives would be used in a compilation.

These dependencies are then written to a makefile in such a way that
make will know which object files must be recompiled when a dependency
has changed.

%prep
%autosetup -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc AUTHORS ChangeLog README.md
%{_bindir}/makedepend
%{_mandir}/man1/makedepend.1%{?ext_man}

%changelog
* Mon Feb  5 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.9
  * This release includes code cleanups and other changes,
    including removing the build time dependency on the xorgproto
    package.
- supersedes u_Avoid-depending-on-xproto.patch
* Tue Jan 31 2023 Stefan Dirsch <sndirsch@suse.com>
- renamed 0001-Avoid-depending-on-xproto.patch to
  u_Avoid-depending-on-xproto.patch, i.e. patch is to be upstreamed
* Tue Jan 31 2023 Fabian Vogt <fvogt@suse.com>
- Add patch to avoid the xproto (+pkgconfig) dependency,
  useful for boo#1207721:
  * 0001-Avoid-depending-on-xproto.patch
* Tue Dec 20 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.0.8:
  + Bug #2: fix regression introduced by fix for bug #1
  - Obsoletes issue2-mr7.patch
  + man page: add line breaks in Synopsis section
* Tue Dec  6 2022 Stefan Dirsch <sndirsch@suse.com>
- issue2-mr7.patch
  * Bug #2: fix regression introduced by fix for bug #1
* Sat Oct 29 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.7
  * gitlab CI: add a basic build test
  * Close fd for reading old Makefile when done, instead of leaking it
  * gitlab CI: stop requiring Signed-off-by in commits
  * Use AC_CONFIG_FILES to replace the deprecated AC_OUTPUT with parameters
  * Thibault DUPONCHELLE (1):
  * Add test case for bug #1 + proposed fix.
* Tue Oct  6 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Drop pkgconfig(xorg-macros) BuildRequires: this is only needed if
  configure.ac/Makefile.am files are being modified and autoreconf
  needs to be started. When using the pristine tarball, upstream
  ran make dist.
* Fri Mar 22 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.6
  * This minor maintenance release fixes some bugs, lifts a limit,
    clears some compiler warnings, boosts performance, and includes
    other janitorial cleanups.
- supersedes u_Escape-special-characters-in-paths.patch
* Fri Mar 18 2016 eich@suse.com
- u_Escape-special-characters-in-paths.patch
  Make gets confused by certain special characters in Makefiles.
  Escape them. This is a problem particularly with ':' in OBS
  paths.
* Sat Aug 17 2013 zaitor@opensuse.org
- Update to version 1.0.5:
  + Don't crash if an option's argument is missing.
  + Assume signal handlers return void, as C89 requires.
  + Unsafe use of strcpy() in makedepend (fdo#56091).
  + Store len in a size_t instead of an int in redirect().
  + Mark fatalerr & catch as _X_NORETURN.
  + Replace deprecated Automake INCLUDES variable with AM_CPPFLAGS.
  + Makedepend rename fails on CIFS mounted shares (fdo#52099).
  + autogen.sh: Implement GNOME Build API.
  + configure: Drop AM_MAINTAINER_MODE.
  + Fix a comment typo.
  + Convert more sprintf calls to snprintf.
  + Remove unnecessary casts from malloc/realloc calls.
  + Remove fallbacks for Imake configuration, assume autoconf.
  + Move i_listlen in struct inclist for better packing in 64-bit
    builds.
  + config: Remove unnecessary calls from configure.ac.
  + Update configure.ac initialization to X.Org standard form.
  + unifdef -U__UNIXOS2__.
  + makedepend: Build with automake-1.13 broken (fdo#59005).
  + configure.ac: use AM_MAINTAINER_MODE.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split makedepend from xorg-x11-util-devel.
  Initial version: 1.0.4.
